@@ -18,45 +18,71 @@ class Pathier(pathlib.Path):
     def __new__(cls, *args, **kwargs):
         if cls is Pathier:
             cls = WindowsPath if os.name == "nt" else PosixPath
-        self = cls._from_parts(args)
+        self = cls._from_parts(args)  # type: ignore
         if not self._flavour.is_supported:
             raise NotImplementedError(
                 "cannot instantiate %r on your system" % (cls.__name__,)
             )
+        if "convert_backslashes" in kwargs:
+            self.convert_backslashes = kwargs["convert_backslashes"]
+        else:
+            self.convert_backslashes = True
         return self
 
+    @property
+    def convert_backslashes(self) -> bool:
+        """If True, when `self.__str__()`/`str(self)` is called, string representations will have double backslashes converted to a forward slash.
+
+        Only affects Windows paths."""
+        try:
+            return self._convert_backslashes
+        except Exception as e:
+            return True
+
+    @convert_backslashes.setter
+    def convert_backslashes(self, should_convert: bool):
+        self._convert_backslashes = should_convert
+
+    def __str__(self) -> str:
+        path = super().__new__(pathlib.Path, self).__str__()  # type: ignore
+        if self.convert_backslashes:
+            path = path.replace("\\", "/")
+        return path
+
     # ===============================================stats===============================================
     @property
     def dob(self) -> datetime.datetime | None:
         """Returns the creation date of this file or directory as a `dateime.datetime` object."""
-        if self.exists():
-            return datetime.datetime.fromtimestamp(self.stat().st_ctime)
-        else:
-            return None
+        return (
+            datetime.datetime.fromtimestamp(self.stat().st_ctime)
+            if self.exists()
+            else None
+        )
 
     @property
     def age(self) -> float | None:
         """Returns the age in seconds of this file or directory."""
-        if self.exists():
-            return (datetime.datetime.now() - self.dob).total_seconds()
-        else:
-            return None
+        return (
+            (datetime.datetime.now() - self.dob).total_seconds() if self.dob else None
+        )
 
     @property
     def mod_date(self) -> datetime.datetime | None:
         """Returns the modification date of this file or directory as a `datetime.datetime` object."""
-        if self.exists():
-            return datetime.datetime.fromtimestamp(self.stat().st_mtime)
-        else:
-            return None
+        return (
+            datetime.datetime.fromtimestamp(self.stat().st_mtime)
+            if self.exists()
+            else None
+        )
 
     @property
     def mod_delta(self) -> float | None:
         """Returns how long ago in seconds this file or directory was modified."""
-        if self.exists():
-            return (datetime.datetime.now() - self.mod_date).total_seconds()
-        else:
-            return None
+        return (
+            (datetime.datetime.now() - self.mod_date).total_seconds()
+            if self.mod_date
+            else None
+        )
 
     @property
     def last_read_time(self) -> datetime.datetime | None:
@@ -64,11 +90,13 @@ class Pathier(pathlib.Path):
         Returns `None` if the file hasn't been read from.
 
         Note: This property is only relative to the lifetime of this `Pathier` instance, not the file itself.
-        i.e. This property will reset if you create a new `Pathier` object pointing to the same file."""
-        if self._last_read_time:
-            return datetime.datetime.fromtimestamp(self._last_read_time)
-        else:
-            return self._last_read_time
+        i.e. This property will reset if you create a new `Pathier` object pointing to the same file.
+        """
+        return (
+            datetime.datetime.fromtimestamp(self._last_read_time)
+            if self._last_read_time
+            else None
+        )
 
     @property
     def modified_since_last_read(self) -> bool:
@@ -82,8 +110,13 @@ class Pathier(pathlib.Path):
         May not be accurate if the file was modified within a couple of seconds of checking this property.
         (For instance, on my machine `self.mod_date` is consistently 1-1.5s in the future from when `self.write_text()` was called according to `time.time()`.)
         """
-
-        return self.last_read_time is None or self.mod_date > self.last_read_time
+        return (
+            False
+            if not self.mod_date
+            or not self.last_read_time
+            or self.mod_date < self.last_read_time
+            else True
+        )
 
     @property
     def size(self) -> int:
@@ -98,27 +131,40 @@ class Pathier(pathlib.Path):
             return sum(file.stat().st_size for file in self.rglob("*.*"))
         return 0
 
+    @property
+    def formatted_size(self) -> str:
+        """The size of this file or directory formatted with `self.format_bytes()`."""
+        return self.format_bytes(self.size)
+
     @staticmethod
     def format_bytes(size: int) -> str:
         """Format `size` with common file size abbreviations and rounded to two decimal places.
         >>> 1234 -> "1.23 kb" """
+        unit = "bytes"
         for unit in ["bytes", "kb", "mb", "gb", "tb", "pb"]:
             if unit != "bytes":
-                size *= 0.001
+                size *= 0.001  # type: ignore
             if size < 1000 or unit == "pb":
-                return f"{round(size, 2)} {unit}"
+                break
+        return f"{round(size, 2)} {unit}"
 
     def is_larger(self, path: Self) -> bool:
         """Returns whether this file or folder is larger than the one pointed to by `path`."""
         return self.size > path.size
 
-    def is_older(self, path: Self) -> bool:
-        """Returns whether this file or folder is older than the one pointed to by `path`."""
-        return self.dob < path.dob
+    def is_older(self, path: Self) -> bool | None:
+        """Returns whether this file or folder is older than the one pointed to by `path`.
 
-    def modified_more_recently(self, path: Self) -> bool:
-        """Returns whether this file or folder was modified more recently than the one pointed to by `path`."""
-        return self.mod_date > path.mod_date
+        Returns `None` if one or both paths don't exist."""
+        return self.dob < path.dob if self.dob and path.dob else None
+
+    def modified_more_recently(self, path: Self) -> bool | None:
+        """Returns whether this file or folder was modified more recently than the one pointed to by `path`.
+
+        Returns `None` if one or both paths don't exist."""
+        return (
+            self.mod_date > path.mod_date if self.mod_date and path.mod_date else None
+        )
 
     # ===============================================navigation===============================================
     def mkcwd(self):
@@ -155,21 +201,21 @@ class Pathier(pathlib.Path):
         """Return a new `Pathier` object that is a parent of this instance.
 
         `name` is case-sensitive and raises an exception if it isn't in `self.parts`.
-        >>> p = Pathier("C:\some\directory\in\your\system")
+        >>> p = Pathier("C:/some/directory/in/your/system")
         >>> print(p.moveup("directory"))
-        >>> "C:\some\directory"
+        >>> "C:/some/directory"
         >>> print(p.moveup("yeet"))
-        >>> "Exception: yeet is not a parent of C:\some\directory\in\your\system" """
+        >>> "Exception: yeet is not a parent of C:/some/directory/in/your/system" """
         if name not in self.parts:
             raise Exception(f"{name} is not a parent of {self}")
-        return Pathier(*(self.parts[: self.parts.index(name) + 1]))
+        return self.__class__(*(self.parts[: self.parts.index(name) + 1]))
 
     def __sub__(self, levels: int) -> Self:
         """Return a new `Pathier` object moved up `levels` number of parents from the current path.
-        >>> p = Pathier("C:\some\directory\in\your\system")
+        >>> p = Pathier("C:/some/directory/in/your/system")
         >>> new_p = p - 3
         >>> print(new_p)
-        >>> "C:\some\directory" """
+        >>> "C:/some/directory" """
         path = self
         for _ in range(levels):
             path = path.parent
@@ -202,14 +248,15 @@ class Pathier(pathlib.Path):
         if name not in self.parts:
             raise Exception(f"{name} is not a parent of {self}")
         if keep_name:
-            return Pathier(*self.parts[self.parts.index(name) :])
-        return Pathier(*self.parts[self.parts.index(name) + 1 :])
+            return self.__class__(*self.parts[self.parts.index(name) :])
+        return self.__class__(*self.parts[self.parts.index(name) + 1 :])
 
     # ============================================write and read============================================
     def mkdir(self, mode: int = 511, parents: bool = True, exist_ok: bool = True):
         """Create this directory.
 
-        Same as `Path().mkdir()` except `parents` and `exist_ok` default to `True` instead of `False`."""
+        Same as `Path().mkdir()` except `parents` and `exist_ok` default to `True` instead of `False`.
+        """
         super().mkdir(mode, parents, exist_ok)
 
     def touch(self):
@@ -239,7 +286,8 @@ class Pathier(pathlib.Path):
 
         If a `TypeError` is raised, the function  will attempt to cast `data` to a `str` and try the write again.
 
-        If a `FileNotFoundError` is raised and `parents = True`, `self.parent` will be created."""
+        If a `FileNotFoundError` is raised and `parents = True`, `self.parent` will be created.
+        """
         write = functools.partial(
             super().write_text,
             encoding=encoding,
@@ -291,7 +339,7 @@ class Pathier(pathlib.Path):
         with self.open("a", encoding=encoding) as file:
             file.write(data)
 
-    def replace(
+    def replace_strings(
         self,
         substitutions: list[tuple[str, str]],
         count: int = -1,
@@ -311,7 +359,8 @@ class Pathier(pathlib.Path):
         >>>
         >>> path.replace([("hello", "yeet"), ("goodbye", "yeehaw")])
         equivalent to
-        >>> path.write_text(path.read_text().replace("hello", "yeet").replace("goodbye", "yeehaw"))"""
+        >>> path.write_text(path.read_text().replace("hello", "yeet").replace("goodbye", "yeehaw"))
+        """
         text = self.read_text(encoding)
         for sub in substitutions:
             text = text.replace(sub[0], sub[1], count)
@@ -435,20 +484,21 @@ class Pathier(pathlib.Path):
 
         `overwrite`: If `True`, files already existing in `new_path` will be overwritten.
         If `False`, only files that don't exist in `new_path` will be copied."""
-        new_path = Pathier(new_path)
+        dst = self.__class__(new_path)
         if self.is_dir():
-            if overwrite or not new_path.exists():
-                shutil.copytree(self, new_path, dirs_exist_ok=True)
+            if overwrite or not dst.exists():
+                dst.mkdir()
+                shutil.copytree(self, dst, dirs_exist_ok=True)
             else:
                 files = self.rglob("*.*")
                 for file in files:
-                    dst = new_path.with_name(file.name)
+                    dst = dst.with_name(file.name)
                     if not dst.exists():
                         shutil.copyfile(file, dst)
         elif self.is_file():
-            if overwrite or not new_path.exists():
-                shutil.copyfile(self, new_path)
-        return new_path
+            if overwrite or not dst.exists():
+                shutil.copyfile(self, dst)
+        return dst
 
     def backup(self, timestamp: bool = False) -> Self | None:
         """Create a copy of this file or directory with `_backup` appended to the path stem.
@@ -465,7 +515,8 @@ class Pathier(pathlib.Path):
         >>> ['some_file.txt', 'some_file_backup.txt']
         >>> path.backup(True)
         >>> list(path.iterdir())
-        >>> ['some_file.txt', 'some_file_backup.txt', 'some_file_backup_04-28-2023-06_25_52_PM.txt']"""
+        >>> ['some_file.txt', 'some_file_backup.txt', 'some_file_backup_04-28-2023-06_25_52_PM.txt']
+        """
         if not self.exists():
             return None
         backup_stem = f"{self.stem}_backup"
